@@ -15,7 +15,7 @@ use List::MoreUtils                 qw(any firstval);
 
 use Mojolicious::Plugin::Vparam::Address;
 
-our $VERSION = '1.7';
+our $VERSION = '1.8';
 
 =encoding utf-8
 
@@ -208,6 +208,20 @@ Get classes for invalid input. Return empty string if no error.
 
 You can set additional I<@classes> to set if field invalid.
 
+=head2 vvalue $name, $default
+
+Get raw input value after validation. Return I<$default> value or empty
+string before validation.
+
+    # Form example:
+    <input name="myparam" value="<%= vvalue 'myparam' %>">
+
+    # Return next code if user just open form without submit and validation:
+    # <input name="myparam" value="">
+
+    # Then user submit form and you validate id. For example user submit "abc":
+    # <input name="myparam" value="abc">
+
 =head2 verrors
 
 Return erorrs count in scalar context. In list context return erorrs hash.
@@ -1422,6 +1436,17 @@ sub register {
         return join ' ', @class;
     });
 
+    $app->helper(vvalue => sub{
+        my ($self, $name, @classes) = @_;
+
+        my @input = $self->can('every_param')
+            ? @{ $self->every_param( $name ) }
+            : $self->param( $name )
+        ;
+
+        return @input > 1 ? \@input : $input[0];
+    });
+
     # Return all errors as Hash or errors count in scalar context.
     $app->helper(verrors => sub{
         my ($self) = @_;
@@ -1498,12 +1523,10 @@ sub register {
             }
 
             # Get value
-            my @input;
-            if( version->new($Mojolicious::VERSION) < version->new(5.48) ) {
-                @input = $self->param( $name );
-            } else {
-                @input = @{ $self->every_param( $name ) };
-            }
+            my @input = $self->can('every_param')
+                ? @{ $self->every_param( $name ) }
+                : $self->param( $name )
+            ;
 
             # Set undefined value if paremeter not set
             # if array then keep it empty
